party-notes
===========
This module adds a notes page to the party type.
You can add any text to a party.

Install
=======

pip install mds-party-notes

Requires
========
- Tryton 6.0

Changes
=======

*6.0.1 - 16.06.2023*

- code optimized

*6.0.0 - 27.08.2021*

- compatibility to Tryton 6.0
